@@ -86,7 +86,7 @@
 #define PLASMA_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef PLASMA_NO_DEPRECATED
-#  define PLASMA_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55c00
+#  define PLASMA_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55d00
 #endif
 #ifdef PLASMA_NO_DEPRECATED_WARNINGS
 #  define PLASMA_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef PLASMA_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define PLASMA_DEPRECATED_WARNINGS_SINCE PLASMA_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define PLASMA_DEPRECATED_WARNINGS_SINCE 0x55c00
+#    define PLASMA_DEPRECATED_WARNINGS_SINCE 0x55d00
 #  endif
 #endif
 
@@ -258,7 +258,7 @@
 #define PLASMA_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef PLASMA_NO_DEPRECATED
-#  define PLASMA_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55c00
+#  define PLASMA_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55d00
 #endif
 #ifdef PLASMA_NO_DEPRECATED_WARNINGS
 #  define PLASMA_DEPRECATED_WARNINGS_SINCE 0
@@ -268,7 +268,7 @@
 #  ifdef PLASMA_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define PLASMA_DEPRECATED_WARNINGS_SINCE PLASMA_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define PLASMA_DEPRECATED_WARNINGS_SINCE 0x55c00
+#    define PLASMA_DEPRECATED_WARNINGS_SINCE 0x55d00
 #  endif
 #endif
 
